"""init

Revision ID: a60eafe5e3f9
Revises:
Create Date: 2024-09-08 08:38:03.290917

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "a60eafe5e3f9"
down_revision: Union[str, None] = None
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "data_sources",
        sa.Column("id", sa.Integer(), autoincrement=True, nullable=False),
        sa.Column("name", sa.String(), nullable=True),
        sa.Column("description", sa.String(), nullable=True),
        sa.Column(
            "type",
            sa.Enum("SQLite", "DuckDB", "SQLServer", name="datasourcetype", length=255),
            nullable=True,
        ),
        sa.Column("conn_str", sa.String(), nullable=True),
        sa.Column("conn_str_encrypted", sa.Boolean(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "sessions",
        sa.Column("id", sa.Integer(), autoincrement=True, nullable=False),
        sa.Column("data_source_id", sa.Integer(), nullable=True),
        sa.Column("model", sa.String(), nullable=True),
        sa.Column("tables", sa.String(), nullable=True),
        sa.Column("schema_name", sa.String(), nullable=True),
        sa.Column("title", sa.String(), nullable=True),
        sa.Column("system_prompt", sa.String(), nullable=True),
        sa.Column("created_at", sa.DateTime(), nullable=True),
        sa.Column("ended_at", sa.DateTime(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_table(
        "settings",
        sa.Column("key", sa.String(), nullable=False),
        sa.Column("value", sa.String(), nullable=True),
        sa.PrimaryKeyConstraint("key"),
    )
    op.create_table(
        "session_messages",
        sa.Column("id", sa.Integer(), autoincrement=True, nullable=False),
        sa.Column("session_id", sa.Integer(), nullable=True),
        sa.Column("content", sa.String(), nullable=True),
        sa.Column("role", sa.String(), nullable=True),
        sa.Column("model", sa.String(), nullable=True),
        sa.Column("parent_message_id", sa.Integer(), nullable=True),
        sa.Column("done", sa.Boolean(), nullable=True),
        sa.Column("copilot_generated", sa.Boolean(), nullable=True),
        sa.Column("is_system_prompt", sa.Boolean(), nullable=True),
        sa.Column("is_error", sa.Boolean(), nullable=True),
        sa.Column("is_streaming", sa.Boolean(), nullable=True),
        sa.Column("generating", sa.Boolean(), nullable=True),
        sa.Column("actions", sa.String(), nullable=True),
        sa.Column("created_at", sa.DateTime(), nullable=True),
        sa.ForeignKeyConstraint(
            ["session_id"],
            ["sessions.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(
        op.f("ix_session_messages_session_id"),
        "session_messages",
        ["session_id"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f("ix_session_messages_session_id"), table_name="session_messages")
    op.drop_table("session_messages")
    op.drop_table("settings")
    op.drop_table("sessions")
    op.drop_table("data_sources")
    # ### end Alembic commands ###
